@@ -1,6 +1,11 @@
 # -*- coding:utf-8 -*-
 
-import unittest
+import sys
+if sys.version_info >= (2, 7):
+    import unittest
+else:
+    import unittest2 as unittest
+
 import time
 
 from limpyd import fields
