@@ -1,6 +1,10 @@
 # -*- coding:utf-8 -*-
 
-import unittest
+import sys
+if sys.version_info >= (2, 7):
+    import unittest
+else:
+    import unittest2 as unittest
 
 import threading
 import time
